@@ -12,9 +12,10 @@
 
 
 from horizon import exceptions
-from horizon.utils.memoized import memoized
+from horizon.utils.memoized import memoized_with_request
 import logging
 from openstack_dashboard.api import base
+from zunclient import api_versions
 from zunclient.common import utils
 from zunclient.v1 import client as zun_client
 
@@ -23,23 +24,44 @@ LOG = logging.getLogger(__name__)
 
 CONTAINER_CREATE_ATTRS = zun_client.containers.CREATION_ATTRIBUTES
 IMAGE_PULL_ATTRS = zun_client.images.PULL_ATTRIBUTES
+API_VERSION = api_versions.APIVersion(api_versions.DEFAULT_API_VERSION)
 
 
-@memoized
-def zunclient(request):
-    zun_url = ""
+def get_auth_params_from_request(request):
+    """Extracts properties needed by zunclient call from the request object.
+
+    These will be used to memoize the calls to zunclient.
+    """
+    endpoint_override = ""
     try:
-        zun_url = base.url_for(request, 'container')
+        endpoint_override = base.url_for(request, 'container')
     except exceptions.ServiceCatalogException:
         LOG.debug('No Container Management service is configured.')
         return None
+    return (
+        request.user.username,
+        request.user.token.id,
+        request.user.tenant_id,
+        endpoint_override
+    )
+
+
+@memoized_with_request(get_auth_params_from_request)
+def zunclient(request_auth_params):
+    (
+        username,
+        token_id,
+        project_id,
+        endpoint_override
+    ) = request_auth_params
 
     LOG.debug('zunclient connection created using the token "%s" and url'
-              '"%s"' % (request.user.token.id, zun_url))
-    c = zun_client.Client(username=request.user.username,
-                          project_id=request.user.tenant_id,
-                          input_auth_token=request.user.token.id,
-                          zun_url=zun_url)
+              ' "%s"' % (token_id, endpoint_override))
+    c = zun_client.Client(username=username,
+                          project_id=project_id,
+                          auth_token=token_id,
+                          endpoint_override=endpoint_override,
+                          api_version=API_VERSION)
     return c
 
 
@@ -54,8 +76,9 @@ def _cleanup_params(attrs, check, **params):
             args[key] = float(value)
         elif key == "memory":
             args[key] = int(value)
-        elif key == "interactive" or key == "nets" \
-                or key == "security_groups" or key == "hints":
+        elif key == "interactive" or key == "mounts" or key == "nets" \
+                or key == "security_groups" or key == "hints"\
+                or key == "auto_remove":
             args[key] = value
         elif key == "restart_policy":
             args[key] = utils.check_restart_policy(value)
@@ -129,9 +152,8 @@ def container_update(request, id, **kwargs):
     return args
 
 
-def container_delete(request, id, force=False):
-    # TODO(shu-mutou): force option should be provided by user.
-    return zunclient(request).containers.delete(id, force=force)
+def container_delete(request, **kwargs):
+    return zunclient(request).containers.delete(**kwargs)
 
 
 def container_list(request, limit=None, marker=None, sort_key=None,
@@ -186,6 +208,10 @@ def container_attach(request, id):
     return zunclient(request).containers.attach(id)
 
 
+def container_resize(request, id, width, height):
+    return zunclient(request).containers.resize(id, width, height)
+
+
 def image_list(request, limit=None, marker=None, sort_key=None,
                sort_dir=None, detail=True):
     return zunclient(request).images.list(limit, marker, sort_key,
