@@ -38,14 +38,6 @@ class Container(generic.View):
         """Get a specific container"""
         return change_to_id(client.container_show(request, id).to_dict())
 
-    @rest_utils.ajax(data_required=True)
-    def delete(self, request, id):
-        """Delete single Container forcely by id.
-
-        Returns HTTP 204 (no content) on successful deletion.
-        """
-        return client.container_delete(request, id, force=True)
-
     @rest_utils.ajax(data_required=True)
     def patch(self, request, id):
         """Update a Container.
@@ -90,6 +82,23 @@ class ContainerActions(generic.View):
             return client.container_kill(request, id, signal)
         elif action == 'attach':
             return client.container_attach(request, id)
+        elif action == 'resize':
+            width = request.DATA.get("width") or 500
+            height = request.DATA.get("height") or 400
+            return client.container_resize(request, id, width, height)
+
+    @rest_utils.ajax(data_required=True)
+    def delete(self, request, id, action):
+        """Delete specified Container with option.
+
+        Returns HTTP 204 (no content) on successful deletion.
+        """
+        opts = {'id': id}
+        if action == 'force':
+            opts['force'] = True
+        elif action == 'stop':
+            opts['stop'] = True
+        return client.container_delete(request, **opts)
 
 
 @urls.register
@@ -114,7 +123,8 @@ class Containers(generic.View):
         Returns HTTP 204 (no content) on successful deletion.
         """
         for id in request.DATA:
-            client.container_delete(request, id)
+            opts = {'id': id}
+            client.container_delete(request, **opts)
 
     @rest_utils.ajax(data_required=True)
     def post(self, request):
