@@ -35,6 +35,7 @@
       deleteContainer: deleteContainer,
       deleteContainers: deleteContainers,
       deleteContainerForce: deleteContainerForce,
+      deleteContainerStop: deleteContainerStop,
       startContainer: startContainer,
       stopContainer: stopContainer,
       logsContainer: logsContainer,
@@ -43,6 +44,7 @@
       unpauseContainer: unpauseContainer,
       executeContainer: executeContainer,
       killContainer: killContainer,
+      resizeContainer: resizeContainer,
       pullImage: pullImage,
       getImages: getImages
     };
@@ -63,9 +65,12 @@
       return apiService.patch(containersPath + id, params).error(error(msg));
     }
 
-    function getContainer(id) {
-      var msg = gettext('Unable to retrieve the Container.');
-      return apiService.get(containersPath + id).error(error(msg));
+    function getContainer(id, suppressError) {
+      var promise = apiService.get(containersPath + id);
+      return suppressError ? promise : promise.error(function() {
+        var msg = gettext('Unable to retrieve the Container.');
+        toastService.add('error', msg);
+      });
     }
 
     function getContainers() {
@@ -88,13 +93,21 @@
     }
 
     function deleteContainerForce(id, suppressError) {
-      var promise = apiService.delete(containersPath + id, [id]);
+      var promise = apiService.delete(containersPath + id + '/force', [id]);
       return suppressError ? promise : promise.error(function() {
         var msg = gettext('Unable to delete forcely the Container with id: %(id)s');
         toastService.add('error', interpolate(msg, { id: id }, true));
       });
     }
 
+    function deleteContainerStop(id, suppressError) {
+      var promise = apiService.delete(containersPath + id + '/stop', [id]);
+      return suppressError ? promise : promise.error(function() {
+        var msg = gettext('Unable to stop and delete the Container with id: %(id)s');
+        toastService.add('error', interpolate(msg, { id: id }, true));
+      });
+    }
+
     function startContainer(id) {
       var msg = gettext('Unable to start Container.');
       return apiService.post(containersPath + id + '/start').error(error(msg));
@@ -135,6 +148,11 @@
       return apiService.post(containersPath + id + '/kill', params).error(error(msg));
     }
 
+    function resizeContainer(id, params) {
+      var msg = gettext('Unable to resize console.');
+      return apiService.post(containersPath + id + '/resize', params).error(error(msg));
+    }
+
     ////////////
     // Images //
     ////////////
